// Importing D3 modules
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Loading data from CSV
csv('https://gist.githubusercontent.com/srinivasaraosankula/78959cba28559fe6802662e0d08a7faf/raw/3d85beaaf77cca46119d32e3a6e9dd66738d6b06/Runs%2520Scored%2520by%2520Sachin%2520in%2520each%2520year.csv')
  .then(data => {
    data.forEach(d => {
    	d.runs = +d.runs;
//Retrieving year from the data
      d.year = new Date(d.year);
    });

const render = data => { 
//Assigning year to x-axis   
  const xValue = d => d.year; 
  const xAxisLabel = 'Year';
//Assigning runs to y-axis 
  const yValue = d => d.runs;
  const yAxisLabel = 'Runs';
  
//Setting dimensions to the graph
  const margin = { top: 40, right: 20, bottom: 38, left: 130 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  
//X-axis scale
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
//Y-axis scale
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

//Place the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  	
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
//Y-axis label dimensions
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
//X-axis label dimensions
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 60)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);


//Generating a line in the graph  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};


    render(data);
  });